pub struct FormulaParseErrorGroup {
pub error_code: String,
pub error_message: String,
pub sheet_name: String,
pub formula_preview: String,
pub count: usize,
pub sample_addresses: Vec<String>,
}Fields
error_code: Stringerror_message: Stringsheet_name: Stringformula_preview: Stringcount: usizesample_addresses: Vec<String>Trait Implementations
Sourceimpl Clone for FormulaParseErrorGroup
impl Clone for FormulaParseErrorGroup
Sourcefn clone(&self) -> FormulaParseErrorGroup
fn clone(&self) -> FormulaParseErrorGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormulaParseErrorGroup
impl Debug for FormulaParseErrorGroup
Sourceimpl<'de> Deserialize<'de> for FormulaParseErrorGroup
impl<'de> Deserialize<'de> for FormulaParseErrorGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FormulaParseErrorGroup
impl JsonSchema for FormulaParseErrorGroup
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FormulaParseErrorGroup
impl RefUnwindSafe for FormulaParseErrorGroup
impl Send for FormulaParseErrorGroup
impl Sync for FormulaParseErrorGroup
impl Unpin for FormulaParseErrorGroup
impl UnsafeUnpin for FormulaParseErrorGroup
impl UnwindSafe for FormulaParseErrorGroup