pub struct DeleteNameResponse {
pub workbook_id: WorkbookId,
pub name: String,
pub deleted: bool,
}Fields
workbook_id: WorkbookIdname: Stringdeleted: boolTrait Implementations
Sourceimpl Clone for DeleteNameResponse
impl Clone for DeleteNameResponse
Sourcefn clone(&self) -> DeleteNameResponse
fn clone(&self) -> DeleteNameResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteNameResponse
impl Debug for DeleteNameResponse
Sourceimpl<'de> Deserialize<'de> for DeleteNameResponse
impl<'de> Deserialize<'de> for DeleteNameResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeleteNameResponse
impl JsonSchema for DeleteNameResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeleteNameResponse
impl RefUnwindSafe for DeleteNameResponse
impl Send for DeleteNameResponse
impl Sync for DeleteNameResponse
impl Unpin for DeleteNameResponse
impl UnsafeUnpin for DeleteNameResponse
impl UnwindSafe for DeleteNameResponse