pub struct GridPayload {
pub sheet: String,
pub anchor: String,
pub columns: Vec<GridColumnHint>,
pub merges: Vec<String>,
pub rows: Vec<GridRow>,
}Fields
sheet: Stringanchor: Stringcolumns: Vec<GridColumnHint>merges: Vec<String>rows: Vec<GridRow>Trait Implementations
Sourceimpl Clone for GridPayload
impl Clone for GridPayload
Sourcefn clone(&self) -> GridPayload
fn clone(&self) -> GridPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GridPayload
impl Debug for GridPayload
Sourceimpl<'de> Deserialize<'de> for GridPayload
impl<'de> Deserialize<'de> for GridPayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GridPayload
impl JsonSchema for GridPayload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GridPayload
impl RefUnwindSafe for GridPayload
impl Send for GridPayload
impl Sync for GridPayload
impl Unpin for GridPayload
impl UnsafeUnpin for GridPayload
impl UnwindSafe for GridPayload