pub struct LayoutPageResponse {
pub workbook_id: WorkbookId,
pub sheet_name: String,
pub range: String,
pub columns: Vec<LayoutPageColumnInfo>,
pub merged_cells: Vec<String>,
pub rows: Vec<LayoutRowInfo>,
pub ascii_render: Option<String>,
pub truncated: bool,
pub notes: Vec<String>,
}Fields
workbook_id: WorkbookIdsheet_name: Stringrange: StringThe effective range that was rendered
columns: Vec<LayoutPageColumnInfo>merged_cells: Vec<String>Merged cell ranges that overlap the rendered region (e.g., [“B1:C1”])
rows: Vec<LayoutRowInfo>ascii_render: Option<String>ASCII art render (present when render=ascii or render=both)
truncated: boolTrue when the requested range was capped to the row/column limits
notes: Vec<String>Trait Implementations
Sourceimpl Clone for LayoutPageResponse
impl Clone for LayoutPageResponse
Sourcefn clone(&self) -> LayoutPageResponse
fn clone(&self) -> LayoutPageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LayoutPageResponse
impl Debug for LayoutPageResponse
Sourceimpl<'de> Deserialize<'de> for LayoutPageResponse
impl<'de> Deserialize<'de> for LayoutPageResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LayoutPageResponse
impl JsonSchema for LayoutPageResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LayoutPageResponse
impl RefUnwindSafe for LayoutPageResponse
impl Send for LayoutPageResponse
impl Sync for LayoutPageResponse
impl Unpin for LayoutPageResponse
impl UnsafeUnpin for LayoutPageResponse
impl UnwindSafe for LayoutPageResponse