pub struct LayoutRowInfo {
pub row: u32,
pub cells: Vec<LayoutCellInfo>,
}Fields
row: u32cells: Vec<LayoutCellInfo>Trait Implementations
Sourceimpl Clone for LayoutRowInfo
impl Clone for LayoutRowInfo
Sourcefn clone(&self) -> LayoutRowInfo
fn clone(&self) -> LayoutRowInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LayoutRowInfo
impl Debug for LayoutRowInfo
Sourceimpl<'de> Deserialize<'de> for LayoutRowInfo
impl<'de> Deserialize<'de> for LayoutRowInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LayoutRowInfo
impl JsonSchema for LayoutRowInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LayoutRowInfo
impl RefUnwindSafe for LayoutRowInfo
impl Send for LayoutRowInfo
impl Sync for LayoutRowInfo
impl Unpin for LayoutRowInfo
impl UnsafeUnpin for LayoutRowInfo
impl UnwindSafe for LayoutRowInfo