pub struct ManifestStubResponse {
pub workbook_id: WorkbookId,
pub slug: String,
pub manifest_yaml: String,
pub sheets: Vec<ManifestSheetStub>,
}Fields
workbook_id: WorkbookIdslug: Stringmanifest_yaml: Stringsheets: Vec<ManifestSheetStub>Trait Implementations
Sourceimpl Clone for ManifestStubResponse
impl Clone for ManifestStubResponse
Sourcefn clone(&self) -> ManifestStubResponse
fn clone(&self) -> ManifestStubResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManifestStubResponse
impl Debug for ManifestStubResponse
Sourceimpl<'de> Deserialize<'de> for ManifestStubResponse
impl<'de> Deserialize<'de> for ManifestStubResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManifestStubResponse
impl JsonSchema for ManifestStubResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ManifestStubResponse
impl RefUnwindSafe for ManifestStubResponse
impl Send for ManifestStubResponse
impl Sync for ManifestStubResponse
impl Unpin for ManifestStubResponse
impl UnsafeUnpin for ManifestStubResponse
impl UnwindSafe for ManifestStubResponse