pub struct NamedRangesResponse {
pub workbook_id: WorkbookId,
pub items: Vec<NamedRangeDescriptor>,
}Fields
workbook_id: WorkbookIditems: Vec<NamedRangeDescriptor>Trait Implementations
Sourceimpl Clone for NamedRangesResponse
impl Clone for NamedRangesResponse
Sourcefn clone(&self) -> NamedRangesResponse
fn clone(&self) -> NamedRangesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NamedRangesResponse
impl Debug for NamedRangesResponse
Sourceimpl<'de> Deserialize<'de> for NamedRangesResponse
impl<'de> Deserialize<'de> for NamedRangesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NamedRangesResponse
impl JsonSchema for NamedRangesResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NamedRangesResponse
impl RefUnwindSafe for NamedRangesResponse
impl Send for NamedRangesResponse
impl Sync for NamedRangesResponse
impl Unpin for NamedRangesResponse
impl UnsafeUnpin for NamedRangesResponse
impl UnwindSafe for NamedRangesResponse