pub struct FormulaReplaceSample {
pub address: String,
pub before: String,
pub after: String,
}Fields
address: Stringbefore: Stringafter: StringTrait Implementations
Sourceimpl Clone for FormulaReplaceSample
impl Clone for FormulaReplaceSample
Sourcefn clone(&self) -> FormulaReplaceSample
fn clone(&self) -> FormulaReplaceSample
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormulaReplaceSample
impl Debug for FormulaReplaceSample
Sourceimpl JsonSchema for FormulaReplaceSample
impl JsonSchema for FormulaReplaceSample
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FormulaReplaceSample
impl RefUnwindSafe for FormulaReplaceSample
impl Send for FormulaReplaceSample
impl Sync for FormulaReplaceSample
impl Unpin for FormulaReplaceSample
impl UnsafeUnpin for FormulaReplaceSample
impl UnwindSafe for FormulaReplaceSample