pub struct ReplaceInFormulasResponse {
pub fork_id: String,
pub mode: String,
pub change_id: Option<String>,
pub formulas_checked: u64,
pub formulas_changed: u64,
pub recalc_needed: bool,
pub samples: Vec<FormulaReplaceSample>,
pub warnings: Vec<String>,
pub formula_parse_diagnostics: Option<FormulaParseDiagnostics>,
}Fields
fork_id: Stringmode: Stringchange_id: Option<String>formulas_checked: u64formulas_changed: u64recalc_needed: boolsamples: Vec<FormulaReplaceSample>warnings: Vec<String>formula_parse_diagnostics: Option<FormulaParseDiagnostics>Trait Implementations
Sourceimpl Debug for ReplaceInFormulasResponse
impl Debug for ReplaceInFormulasResponse
Sourceimpl JsonSchema for ReplaceInFormulasResponse
impl JsonSchema for ReplaceInFormulasResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReplaceInFormulasResponse
impl RefUnwindSafe for ReplaceInFormulasResponse
impl Send for ReplaceInFormulasResponse
impl Sync for ReplaceInFormulasResponse
impl Unpin for ReplaceInFormulasResponse
impl UnsafeUnpin for ReplaceInFormulasResponse
impl UnwindSafe for ReplaceInFormulasResponse