pub struct ExecuteManifestResponse {
pub workbook_id: WorkbookId,
pub outputs: Value,
}Fields
workbook_id: WorkbookIdoutputs: ValueTrait Implementations
Sourceimpl Clone for ExecuteManifestResponse
impl Clone for ExecuteManifestResponse
Sourcefn clone(&self) -> ExecuteManifestResponse
fn clone(&self) -> ExecuteManifestResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecuteManifestResponse
impl Debug for ExecuteManifestResponse
Sourceimpl<'de> Deserialize<'de> for ExecuteManifestResponse
impl<'de> Deserialize<'de> for ExecuteManifestResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExecuteManifestResponse
impl JsonSchema for ExecuteManifestResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExecuteManifestResponse
impl RefUnwindSafe for ExecuteManifestResponse
impl Send for ExecuteManifestResponse
impl Sync for ExecuteManifestResponse
impl Unpin for ExecuteManifestResponse
impl UnsafeUnpin for ExecuteManifestResponse
impl UnwindSafe for ExecuteManifestResponse