pub struct ManifestStubParams {
pub workbook_or_fork_id: WorkbookId,
pub sheet_filter: Option<String>,
}Fields
workbook_or_fork_id: WorkbookIdsheet_filter: Option<String>Trait Implementations
Sourceimpl Debug for ManifestStubParams
impl Debug for ManifestStubParams
Sourceimpl<'de> Deserialize<'de> for ManifestStubParams
impl<'de> Deserialize<'de> for ManifestStubParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManifestStubParams
impl JsonSchema for ManifestStubParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ManifestStubParams
impl RefUnwindSafe for ManifestStubParams
impl Send for ManifestStubParams
impl Sync for ManifestStubParams
impl Unpin for ManifestStubParams
impl UnsafeUnpin for ManifestStubParams
impl UnwindSafe for ManifestStubParams