pub struct ShiftedSpan {
pub op_index: usize,
pub sheet_name: String,
pub axis: String,
pub description: String,
pub at: u32,
pub count: u32,
pub direction: String,
}Expand description
Describes a row/column span that would be shifted by a structure op.
Fields
op_index: usizesheet_name: Stringaxis: Stringdescription: StringHuman-readable description, e.g. “rows 5..∞ shift +3”.
at: u32count: u32direction: StringTrait Implementations
Sourceimpl Clone for ShiftedSpan
impl Clone for ShiftedSpan
Sourcefn clone(&self) -> ShiftedSpan
fn clone(&self) -> ShiftedSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShiftedSpan
impl Debug for ShiftedSpan
Sourceimpl<'de> Deserialize<'de> for ShiftedSpan
impl<'de> Deserialize<'de> for ShiftedSpan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShiftedSpan
impl JsonSchema for ShiftedSpan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShiftedSpan
impl RefUnwindSafe for ShiftedSpan
impl Send for ShiftedSpan
impl Sync for ShiftedSpan
impl Unpin for ShiftedSpan
impl UnsafeUnpin for ShiftedSpan
impl UnwindSafe for ShiftedSpan