pub struct ErrorDelta {
pub address: String,
pub before_error: Option<String>,
pub after_error: Option<String>,
pub before_formula: Option<String>,
pub after_formula: Option<String>,
}Fields
address: Stringbefore_error: Option<String>after_error: Option<String>before_formula: Option<String>after_formula: Option<String>Trait Implementations
Sourceimpl Clone for ErrorDelta
impl Clone for ErrorDelta
Sourcefn clone(&self) -> ErrorDelta
fn clone(&self) -> ErrorDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ErrorDelta
impl Debug for ErrorDelta
Sourceimpl JsonSchema for ErrorDelta
impl JsonSchema for ErrorDelta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ErrorDelta
impl RefUnwindSafe for ErrorDelta
impl Send for ErrorDelta
impl Sync for ErrorDelta
impl Unpin for ErrorDelta
impl UnsafeUnpin for ErrorDelta
impl UnwindSafe for ErrorDelta