pub struct NamedRangeDelta {
pub name: String,
pub scope_kind: Option<NamedRangeScope>,
pub scope_sheet_name: Option<String>,
pub change: String,
pub before_refers_to: Option<String>,
pub after_refers_to: Option<String>,
pub before_kind: Option<NamedItemKind>,
pub after_kind: Option<NamedItemKind>,
}Fields
name: Stringscope_kind: Option<NamedRangeScope>scope_sheet_name: Option<String>change: Stringbefore_refers_to: Option<String>after_refers_to: Option<String>before_kind: Option<NamedItemKind>after_kind: Option<NamedItemKind>Trait Implementations
Sourceimpl Clone for NamedRangeDelta
impl Clone for NamedRangeDelta
Sourcefn clone(&self) -> NamedRangeDelta
fn clone(&self) -> NamedRangeDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NamedRangeDelta
impl Debug for NamedRangeDelta
Sourceimpl JsonSchema for NamedRangeDelta
impl JsonSchema for NamedRangeDelta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NamedRangeDelta
impl RefUnwindSafe for NamedRangeDelta
impl Send for NamedRangeDelta
impl Sync for NamedRangeDelta
impl Unpin for NamedRangeDelta
impl UnsafeUnpin for NamedRangeDelta
impl UnwindSafe for NamedRangeDelta