pub struct TargetClassificationCounts {
pub unchanged: u32,
pub direct_edit: u32,
pub recalc_result: u32,
pub formula_shift: u32,
pub new_error: u32,
}Fields
unchanged: u32direct_edit: u32recalc_result: u32formula_shift: u32new_error: u32Trait Implementations
Sourceimpl Clone for TargetClassificationCounts
impl Clone for TargetClassificationCounts
Sourcefn clone(&self) -> TargetClassificationCounts
fn clone(&self) -> TargetClassificationCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetClassificationCounts
impl Debug for TargetClassificationCounts
Sourceimpl Default for TargetClassificationCounts
impl Default for TargetClassificationCounts
Sourcefn default() -> TargetClassificationCounts
fn default() -> TargetClassificationCounts
Returns the “default value” for a type. Read more
Sourceimpl JsonSchema for TargetClassificationCounts
impl JsonSchema for TargetClassificationCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TargetClassificationCounts
impl RefUnwindSafe for TargetClassificationCounts
impl Send for TargetClassificationCounts
impl Sync for TargetClassificationCounts
impl Unpin for TargetClassificationCounts
impl UnsafeUnpin for TargetClassificationCounts
impl UnwindSafe for TargetClassificationCounts