pub struct TargetDelta {
pub address: String,
pub before: Option<CellValue>,
pub after: Option<CellValue>,
pub before_formula: Option<String>,
pub after_formula: Option<String>,
pub classification: String,
pub changed: bool,
}Fields
address: Stringbefore: Option<CellValue>after: Option<CellValue>before_formula: Option<String>after_formula: Option<String>classification: Stringchanged: boolTrait Implementations
Sourceimpl Clone for TargetDelta
impl Clone for TargetDelta
Sourcefn clone(&self) -> TargetDelta
fn clone(&self) -> TargetDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TargetDelta
impl Debug for TargetDelta
Sourceimpl JsonSchema for TargetDelta
impl JsonSchema for TargetDelta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TargetDelta
impl RefUnwindSafe for TargetDelta
impl Send for TargetDelta
impl Sync for TargetDelta
impl Unpin for TargetDelta
impl UnsafeUnpin for TargetDelta
impl UnwindSafe for TargetDelta