pub struct VerifySummary {
pub target_count: u32,
pub changed_targets: u32,
pub new_error_count: u32,
pub resolved_error_count: u32,
pub preexisting_error_count: u32,
pub named_range_delta_count: u32,
pub target_classification_counts: TargetClassificationCounts,
}Fields
target_count: u32changed_targets: u32new_error_count: u32resolved_error_count: u32preexisting_error_count: u32named_range_delta_count: u32target_classification_counts: TargetClassificationCountsTrait Implementations
Sourceimpl Clone for VerifySummary
impl Clone for VerifySummary
Sourcefn clone(&self) -> VerifySummary
fn clone(&self) -> VerifySummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifySummary
impl Debug for VerifySummary
Sourceimpl JsonSchema for VerifySummary
impl JsonSchema for VerifySummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VerifySummary
impl RefUnwindSafe for VerifySummary
impl Send for VerifySummary
impl Sync for VerifySummary
impl Unpin for VerifySummary
impl UnsafeUnpin for VerifySummary
impl UnwindSafe for VerifySummary