build_simple_dxf_style

Function build_simple_dxf_style 

pub fn build_simple_dxf_style(
    fill_argb: &str,
    font_argb: &str,
    bold: bool,
) -> Style
Build a minimal style intended for conditional formatting (OOXML dxf).

Note: umya-spreadsheet materializes/deduplicates dxf records at write time based on the style hash. Keeping this style deterministic helps reuse the same dxf.